@@ -12,7 +12,7 @@ class QNewNotebookDialog : public QDialog
     Q_OBJECT
 
 public:
-    QNewNotebookDialog(QvernoteAPI* hEvernote, QWidget *parent = 0);
+    QNewNotebookDialog(QWidget *parent = 0);
     ~QNewNotebookDialog();
 
 public slots:
@@ -23,7 +23,6 @@ signals:
 
 private:
     Ui::QNewNotebookDialogClass ui;
-    QvernoteAPI* m_hEvernote;
 };
 
 #endif // QNEWNOTEBOOKDIALOG_H
