@@ -16,12 +16,10 @@
 #include "QNotesView.h"
 
 #ifdef Q_WS_MAEMO_5
-#include <QAbstractKineticScroller>
-#include "QMaemoTextSelectionSupressor.h"
 #include "modest_interface_p.h"
 #endif
 
-QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reader, QWidget *parent)
+QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
     : QvernoteWindow(parent), m_Note(note), isNewNote(bIsNewNote), nTodoTagCount(0)
 {
 	ui.setupUi(this);
@@ -29,6 +27,8 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 	//QObject::connect(ui.wvNoteEdit, SIGNAL(loadFinished(bool)), this, SLOT(resizeWebView()));
 	//m_hEvernote = dynamic_cast<QNotesView*>(this->parentWidget())->getHandle();
 	m_hEvernote = QvernoteAPI::Instance();
+	ui.wvNoteEdit->settings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls, false);
+	ui.wvNoteEdit->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
 
 	if(isNewNote)
 	{
@@ -38,24 +38,24 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 	else
 	{
 		// Load and convert note content
-		if(reader)
-			enmlReader = shared_ptr<QEnmlReader>(reader);
+		enmlReader = shared_ptr<QEnmlReader>(new QEnmlReader());
+
+		if(m_Note.attributes.source != "web.clip")
+			enmlReader->parse(m_Note);
 		else
-		{
-			enmlReader = shared_ptr<QEnmlReader>(new QEnmlReader(m_Note, m_hEvernote));
-			enmlReader->parse();
-		}
+			enmlReader->parse(m_Note, 500000);
+
 		nTodoTagCount = enmlReader->getTodoCount();
 		m_HtmlData = enmlReader->getHtml();
 
 		this->setWindowTitle("Edit note - " + QString::fromUtf8(m_Note.title.c_str()));
 
 		//qDebug() << __FUNCTION__ << m_HtmlData;
+
 		ui.wvNoteEdit->setHtml(m_HtmlData);
 		ui.leNoteTitle->setText(QString::fromUtf8(m_Note.title.c_str()));
 	}
 
-	ui.wvNoteEdit->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
 
 
 	//QObject::connect(ui.wvNoteEdit->page(), SIGNAL(contentsChanged()), this, SLOT(resizeWebView()));
@@ -69,7 +69,7 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 
 
 #ifdef Q_WS_MAEMO_5
-	QMaemoTextSelectionSupressor* supressor = new QMaemoTextSelectionSupressor(ui.wvNoteEdit);
+	supressor = new QMaemoTextSelectionSupressor(ui.wvNoteEdit);
 	supressor->enable();
 #endif
 
@@ -137,14 +137,9 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader* reade
 
 QNoteEditWindow::~QNoteEditWindow()
 {
-
-}
-
-void QNoteEditWindow::hideEvent ( QHideEvent * )
-{
-	//dynamic_cast<QNotesView*>(this->parentWidget())->clearNote(m_Note);
-	//qDebug() << __FUNCTION__ << "hide";
-	//emit noteUpdated();
+#ifdef Q_WS_MAEMO_5
+	delete supressor;
+#endif
 }
 
 void QNoteEditWindow::saveNote()
@@ -206,7 +201,7 @@ void QNoteEditWindow::noteSaveFailure()
 	}
 
 	setProgressIndicator(false);
-	close();
+	//close();
 }
 
 void QNoteEditWindow::toggleBoldStyle()
@@ -316,8 +311,9 @@ void QNoteEditWindow::resizeWebView()
 
 void QNoteEditWindow::openTagSelectorDialog()
 {
-	QTagSelectorDialog* p_Dlg = new QTagSelectorDialog(m_Note, this);
-	p_Dlg->exec();
+	QTagSelectorDialog* pDlg = new QTagSelectorDialog(m_Note, this);
+	pDlg->exec();
+	delete pDlg;
 }
 
 void QNoteEditWindow::setTag(bool state, Tag tag)
