@@ -8,6 +8,9 @@
 #include "QEnmlWriter.h"
 #include "QEnmlReader.h"
 #include <QWebElement>
+#ifdef Q_WS_MAEMO_5
+#include "QMaemoTextSelectionSupressor.h"
+#endif
 
 
 class QNoteEditWindow : public QvernoteWindow
@@ -15,11 +18,9 @@ class QNoteEditWindow : public QvernoteWindow
     Q_OBJECT
 
 public:
-    QNoteEditWindow(Note& note, bool bIsNewNote, QEnmlReader *reader = 0, QWidget *parent = 0);
+    QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent = 0);
     ~QNoteEditWindow();
 
-    void hideEvent ( QHideEvent * );
-
 signals:
     void noteListUpdated();
     void noteUpdated();
@@ -42,7 +43,7 @@ public slots:
     void zoomoutView();
 
     bool backgroundJobCallback() { return createNote(); }
-    void jobDoneCallback() { emit noteUpdated(); close(); }
+    void jobDoneCallback() { emit noteUpdated(); }
     void jobFailedCallback() { noteSaveFailure(); }
 
     /* JS API slots */
@@ -61,6 +62,9 @@ private:
     shared_ptr<QEnmlReader> enmlReader;
     shared_ptr<QEnmlWriter> enmlWriter;
     int nTodoTagCount;
+#ifdef Q_WS_MAEMO_5
+	QMaemoTextSelectionSupressor* supressor;
+#endif
 };
 
 #endif // QNOTEEDITWINDOW_H
