@@ -56,8 +56,13 @@ QNotesView::QNotesView(const Notebook& notebook, QWidget *parent)
 
 	QObject::connect(ui.actionDelete_notes, SIGNAL(triggered(bool)), this, SLOT(loadDeleteNotesView()));
 
+	m_pKeyGrabber = shared_ptr<QKeyGrabber>(new QKeyGrabber("", this));
+	m_pKeyGrabber->setVisible(false);
+	QObject::connect(m_pKeyGrabber.get(), SIGNAL(redrawParentContents(QString)), this, SLOT(redrawNoteList(QString)));
+	ui.gridLayout->addWidget(m_pKeyGrabber.get(), 2, 0);
+
 	setProgressIndicator(true);
-	m_pBackgroundJob->start();
+	reloadNotes();
 	displayInformationBox("Loading notes. Please wait...");
 }
 
@@ -68,7 +73,8 @@ QNotesView::QNotesView(QString windowTitle, QWidget *parent)
 	ui.setupUi(this);
 
 	this->setWindowTitle(windowTitle);
-	ui.pbNewNote->setVisible(false);
+	//ui.pbNewNote->setVisible(false);
+	m_hEvernote->getDefaultNotebook(m_Notebook);
 
 	switch(QvernoteSettings::Instance()->getNotesView()) {
 	case QvernoteSettings::NV_LIST:
@@ -84,6 +90,13 @@ QNotesView::QNotesView(QString windowTitle, QWidget *parent)
 	ui.gridLayout_2->addWidget(dynamic_cast<QWidget*>(m_pNoteListViewWidget), 1, 0, 1, 2);
 	ui.gridLayout_2->setAlignment(Qt::AlignTop);
 	QObject::connect(ui.actionDelete_notes, SIGNAL(triggered(bool)), this, SLOT(loadDeleteNotesView()));
+	QObject::connect(ui.pbNewNote, SIGNAL(clicked()), this, SLOT(openNewNoteWindow()));
+
+	m_pKeyGrabber = shared_ptr<QKeyGrabber>(new QKeyGrabber("", this));
+	m_pKeyGrabber->setVisible(false);
+	QObject::connect(m_pKeyGrabber.get(), SIGNAL(redrawParentContents(QString)), this, SLOT(redrawNoteList(QString)));
+	ui.gridLayout->addWidget(m_pKeyGrabber.get(), 2, 0);
+
 	setProgressIndicator(true);
 	displayInformationBox("Loading notes. Please wait...");
 	loadNotesIntoView();
@@ -96,6 +109,7 @@ QNotesView::~QNotesView()
 
 void QNotesView::reloadNotes()
 {
+	ui.menuBar->setEnabled(false);
 	m_pBackgroundJob->start();
 }
 
@@ -109,62 +123,38 @@ void QNotesView::openNewNoteWindow()
 {
 	Note newNote;// = new Note();
 	newNote.notebookGuid = m_Notebook.guid;
-	QNoteEditWindow* pNoteEditWindow = new QNoteEditWindow(newNote, true, NULL, this);
-	//QObject::connect(pNoteEditWindow, SIGNAL(noteListUpdated()),this, SLOT(loadNotesIntoView()));
-	QObject::connect(pNoteEditWindow, SIGNAL(noteUpdated()), this, SLOT(reloadNotes()));
-	pNoteEditWindow->show();
+
+	m_pNoteEditWindow = shared_ptr<QNoteEditWindow>(new QNoteEditWindow(newNote, true, this));
+	QObject::connect(m_pNoteEditWindow.get(), SIGNAL(noteUpdated()), this, SLOT(reloadNotes()));
+	m_pNoteEditWindow->show();
 }
 
 void QNotesView::openNoteViewer(Note& note)
 {
-	QNoteViewWindow* pWnd = new QNoteViewWindow(note, this);
-	//connect(pWnd, SIGNAL(startEditorSignal(Note&, QEnmlReader*)), this, SLOT(openNoteEditor(Note&, QEnmlReader*)));
-	pWnd->show();
+	m_pNoteViewWindow = shared_ptr<QNoteViewWindow>(new QNoteViewWindow(note, this));
+	m_pNoteViewWindow->show();
 }
 
 void QNotesView::getNextNote(Note& nextNote)
 {
-	//QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
-	//QListWidgetItem* nextItem = ui.lvNoteList->item(ui.lvNoteList->row(l[0]) + 1);
-
-
 	if(m_pNoteListViewWidget->nextNote(nextNote) == false)
 	{
 		displayInformationBox("This is the last note");
 	}
-	/*else
-	{
-		//QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(nextItem);
-		//ui.lvNoteList->setItemSelected(nextItem, true);
-		//nextNote = w->getNote();
-	}
-	*/
 }
 
 void QNotesView::getPrevNote(Note& prevNote)
 {
-	//QList<QListWidgetItem*> l = ui.lvNoteList->selectedItems();
-
 	if(m_pNoteListViewWidget->prevNote(prevNote) == false)
 	{
 		displayInformationBox("This is the first note");
 	}
-
-	/*
-	else
-	{
-		QListWidgetItem* prevItem = ui.lvNoteList->item(ui.lvNoteList->row(l[0]) - 1);
-		ui.lvNoteList->setItemSelected(prevItem, true);
-		QNoteListItemWidget* w = (QNoteListItemWidget*)ui.lvNoteList->itemWidget(prevItem);
-		prevNote = w->getNote();
-	}
-	*/
 }
 
 void QNotesView::loadDeleteNotesView()
 {
-	QDeleteNotesView* p_Wnd = new QDeleteNotesView(QString(m_Notebook.name.c_str()), this);
-	p_Wnd->show();
+	m_pDeleteNotesView = shared_ptr<QDeleteNotesView>(new QDeleteNotesView(QString(m_Notebook.name.c_str()), this));
+	m_pDeleteNotesView->show();
 }
 
 void QNotesView::notesViewShutdown()
@@ -194,7 +184,9 @@ void QNotesView::clearNote(Note& m_Note)
 		(*i).data.body.clear();
 		(*i).data.body.reserve(0);
 		(*i).recognition.body.clear();
+		(*i).recognition.body.reserve(0);
 		(*i).alternateData.body.clear();
+		(*i).alternateData.body.reserve(0);
 	}
 }
 
@@ -202,10 +194,9 @@ void QNotesView::keyPressEvent(QKeyEvent* event)
 {
 	if(!isSearchShown && !isSynchronizing)
 	{
-		QKeyGrabber* dlg = new QKeyGrabber(event->text(), this);
-		ui.gridLayout->addWidget(dlg, 2, 0);
-		QObject::connect(dlg, SIGNAL(redrawParentContents(QString)), this, SLOT(redrawNoteList(QString)));
 		isSearchShown = true;
+		m_pKeyGrabber->setText(event->text());
+		m_pKeyGrabber->setVisible(true);
 	}
 
 	QvernoteWindow::keyPressEvent(event);
@@ -230,6 +221,7 @@ void QNotesView::onNoteLoadDone()
 	ui.scrollArea->ensureVisible(0, 0);
 	setProgressIndicator(false);
 	isSynchronizing = false;
+	ui.menuBar->setEnabled(true);
 }
 
 void QNotesView::orientationChanged()
