@@ -10,6 +10,8 @@ QvernoteLoginDialog::QvernoteLoginDialog(QWidget *parent)
 
 	QObject::connect(ui.pbSignin, SIGNAL(clicked()), this, SLOT(evernoteLogin()));
 	QObject::connect(ui.pbWorkOffline, SIGNAL(clicked()), this, SLOT(setWorkOffline()));
+	ui.leUsername->setInputMethodHints(Qt::ImhPreferLowercase|Qt::ImhNoAutoUppercase);
+	ui.lePassword->setInputMethodHints(Qt::ImhPreferLowercase|Qt::ImhNoAutoUppercase|Qt::ImhHiddenText);
 }
 
 QvernoteLoginDialog::~QvernoteLoginDialog()
